<?php

/**
 * @file
 * Provides TextMaster translation plugin controller.
 */

/**
 * TextMaster translation plugin controller.
 */
class TMGMTTextmasterPluginController extends TMGMTDefaultTranslatorPluginController {

  /**
   * {@inheritdoc}
   */
  public function getSupportedRemoteLanguages(TMGMTTranslator $translator) {
    /** @var TmgmtTextmasterConnector $connector */
    $connector = $this->getConnector($translator);
    return $connector->getSupportedRemoteLanguages();
  }

  /**
   * {@inheritdoc}
   */
  public function isAvailable(TMGMTTranslator $translator) {
    /** @var TmgmtTextmasterConnector $connector */
    $connector = $this->getConnector($translator);
    return $connector->checkTextmasterAuthentication();
  }

  /**
   * {@inheritdoc}
   */
  public function requestTranslation(TMGMTJob $job) {
    /** @var TmgmtTextmasterConnector $connector */
    $connector = $this->getConnector($job->getTranslator());
    $connector->requestJobItemsTranslation($job->getItems());
  }

  /**
   * {@inheritdoc}
   */
  public function defaultSettings() {
    $defaults = parent::defaultSettings();
    // Enable CDATA for content encoding in File translator.
    $defaults['xliff_cdata'] = TRUE;
    $defaults['textmaster_service_url'] = TMGMTTextmasterTranslatorUIController::TEXTMASTER_API_URL;
    return $defaults;
  }

  /**
   * {@inheritdoc}
   */
  public function abortTranslation(TMGMTJob $job) {
    $mappings = $job->getRemoteMappings();
    $mapping = end($mappings);
    /** @var TmgmtTextmasterConnector $connector */
    $connector = $this->getConnector($job->getTranslator());
    $project_id = $mapping->remote_identifier_2;
    $project_info = $connector->getTmProject($project_id);
    if (!in_array($project_info['status'], ['in_creation', 'in_progress'])) {
      $job->addMessage('Could not cancel the project "@job_title" with status "@status"', [
        '@status' => $project_info['status'],
        '@job_title' => $job->label(),
      ]);
      return FALSE;
    }
    if ($project_info['status'] != 'in_creation') {
      $connector->pauseTmProject($project_id);
    }
    $connector->cancelTmProject($project_id);
    $job->aborted();
    return TRUE;
  }

  /**
   * Gets TextMaster service connector.
   *
   * @param TMGMTTranslator $translator
   *   Current job translator.
   *
   * @return TmgmtTextmasterConnector
   *   TextMaster connector instance.
   */
  public function getConnector(TMGMTTranslator $translator) {
    return new TmgmtTextmasterConnector(
      $translator->getSetting('textmaster_service_url'),
      $translator->getSetting('textmaster_api_key'),
      $translator->getSetting('textmaster_api_secret'),
      $translator
    );
  }

}
