<?php

/**
 * Field handler which shows the operations for a job item.
 *
 * @ingroup views_field_handlers
 */
class TmgmtTextmasterHandlerFieldTmgmtJobItemOperations extends tmgmt_handler_field_tmgmt_job_item_operations {

  /**
   * {@inheritdoc}
   */
  public function render($values) {
    /** @var TMGMTJobItem $item */
    $item = $this->get_value($values);
    // Get the mapping only for the last created Project.
    $mappings = $item->getRemoteMappings();
    $remote_mapping = end($mappings);
    if (empty($remote_mapping)) {
      return parent::render($values);
    }
    $module_name = $remote_mapping->remote_identifier_1;
    $project_id = $remote_mapping->remote_identifier_2;
    $document_id = $remote_mapping->remote_identifier_3;
    if (!$project_id || $module_name != 'tmgmt_textmaster') {
      return parent::render($values);
    }
    // Copy/paste of parent render method.
    $element = [];
    $element['#theme'] = 'links';
    $element['#attributes'] = ['class' => ['inline']];
    $uri = $item->uri();
    if ($item->getCountTranslated() > 0 && entity_access('accept', 'tmgmt_job_item', $item)) {
      $element['#links']['review'] = [
        'href' => $uri['path'],
        'query' => ['destination' => current_path()],
        'title' => t('review'),
      ];
    }
    // Do not display view on unprocessed jobs.
    elseif (!$item->getJob()->isUnprocessed()) {
      $element['#links']['view'] = [
        'href' => $uri['path'],
        'query' => ['destination' => current_path()],
        'title' => t('view'),
      ];
    }
    if (user_access('administer tmgmt') && !$item->isAccepted()) {
      $element['#links']['delete'] = [
        'href' => 'admin/tmgmt/items/' . $item->tjiid . '/delete',
        'query' => ['destination' => current_path()],
        'title' => t('delete'),
      ];
    }

    // Add view_on_tm operation for TextMaster Job Items.
    $textmaster_app_url = TMGMTTextmasterTranslatorUIController::getApplicationUrl($item->getTranslator());
    $element['#links']['view_on_tm'] = [
      'href' => url($textmaster_app_url . '/clients/projects/' . $project_id . '/documents/' . $document_id, [
        'external' => TRUE,
      ]),
      'attributes' => [
        'target' => '_blank',
      ],
      'query' => ['destination' => current_path()],
      'title' => t('view on TextMaster'),
    ];

    return drupal_render($element);
  }

}
