<?php

/**
 * Field handler which shows the operations for a job.
 *
 * @ingroup views_field_handlers
 */
class TmgmtTextmasterHandlerFieldTmgmtJobOperations extends tmgmt_handler_field_tmgmt_job_operations {

  /**
   * {@inheritdoc}
   */
  public function render($values) {
    /** @var TMGMTJob $job */
    $job = $this->get_value($values);
    if ($job->translator != 'textmaster') {
      return parent::render($values);
    }
    $project_id = tmgmt_textmaster_get_project_by_job_id($job->tjid);
    if (!$project_id) {
      return parent::render($values);
    }
    // Copy/paste of parent render method.
    $element = [];
    $element['#theme'] = 'links';
    $element['#attributes'] = ['class' => ['inline']];
    $uri = $job->uri();
    if ($job->isSubmittable() && entity_access('submit', 'tmgmt_job', $job)) {
      $element['#links']['submit'] = [
        'href' => $uri['path'],
        'query' => ['destination' => current_path()],
        'title' => t('submit'),
      ];
    }
    else {
      $element['#links']['manage'] = [
        'href' => $uri['path'],
        'title' => t('manage'),
      ];
    }
    if ($job->isAbortable() && entity_access('submit', 'tmgmt_job', $job)) {
      $element['#links']['cancel'] = [
        'href' => 'admin/tmgmt/jobs/' . $job->tjid . '/abort',
        'query' => ['destination' => current_path()],
        'title' => t('abort'),
      ];
    }
    if ($job->isDeletable() && user_access('administer tmgmt')) {
      $element['#links']['delete'] = [
        'href' => 'admin/tmgmt/jobs/' . $job->tjid . '/delete',
        'query' => ['destination' => current_path()],
        'title' => t('delete'),
      ];
    }

    // Add view_on_tm operation for TextMaster Jobs.
    $textmaster_app_url = TMGMTTextmasterTranslatorUIController::getApplicationUrl($job->getTranslator());
    $element['#links']['view_on_tm'] = [
      'href' => url($textmaster_app_url . '/clients/projects/' . $project_id, [
        'external' => TRUE,
      ]),
      'attributes' => [
        'target' => '_blank',
      ],
      'query' => ['destination' => current_path()],
      'title' => t('view on TextMaster'),
    ];
    // Add launch operation for TextMaster Jobs.
    $mappings = $job->getRemoteMappings();
    $job_remote_data = end($mappings);
    $auto_launch = $job_remote_data->remote_data['TemplateAutoLaunch'];
    if ($job->isState(TMGMT_JOB_STATE_UNPROCESSED) && !$auto_launch) {
      $element['#links']['launch'] = [
        'href' => 'admin/tmgmt/jobs/' . $job->tjid . '/' . $project_id . '/launch',
        'query' => ['destination' => current_path()],
        'title' => t('launch'),
      ];
    }
    return drupal_render($element);
  }

}
